@@ -12,8 +12,6 @@ from django.http import HttpResponse, HttpResponseNotAllowed, HttpResponseBadReq
 from django.shortcuts import get_object_or_404
 from django.views.decorators.http import require_POST
 from django.views.decorators.csrf import csrf_exempt
-from ebaysuds import EbaySuds
-from suds.plugin import PluginContainer
 
 from . import NOTIFICATION_PAYLOADS, NOTIFICATION_TYPES
 from .models import UserToken
@@ -34,7 +32,7 @@ def get_notification_url(username=None):
 
 @require_POST
 @csrf_exempt
-def notification(request, username=None):
+def notification(request, username=None, _validate=True):
     if settings.DEBUG:
         with open(os.path.join(settings.PROJECT_ROOT, 'last_request.pkl'), 'wb') as output:
             meta = dict([(k,v) for k,v in request.META.items() if isinstance(v, basestring)])
@@ -64,7 +62,9 @@ def notification(request, username=None):
         log.error(msg)
         return HttpResponseBadRequest(msg)
 
-    nh_kwargs = {}
+    nh_kwargs = {
+        '_validate': _validate,
+    }
     if username is not None:
         user = get_object_or_404(UserToken, ebay_username__iexact=username)
         nh_kwargs['token'] = user.token
